from distutils.core import setup

setup(
    name        =   'dgzi-nester',
    version     =   '1.0.3',
    py_modules  =   ['nester'],
    author      =   'guangzhao.di',
    author_email=   '1280029266@qq.com',
    url         =   'http://dgz66.com',
    description =   'A simple distutils test',
    )
